@@ -2,7 +2,7 @@ import phonenumbers
 from django import forms
 from django.core import checks
 from django.db.models import Model
-from django.test import TestCase, override_settings
+from django.test import SimpleTestCase, TestCase, override_settings
 from django.utils.encoding import force_str
 from phonenumbers import phonenumberutil
 
@@ -11,7 +11,7 @@ from phonenumber_field.modelfields import PhoneNumberField
 from phonenumber_field.phonenumber import PhoneNumber, to_python
 
 from . import models
-from .forms import CustomPhoneNumberFormField, PhoneNumberForm
+from .forms import ARPhoneNumberForm, CustomPhoneNumberFormField, PhoneNumberForm
 
 ALGERIAN_PHONE_NUMBER = "+213799136332"
 
@@ -393,7 +393,7 @@ class PhoneNumberFieldAppTest(TestCase):
         self.assertIsInstance(models.TestModel.phone, modelfields.PhoneNumberDescriptor)
 
 
-class RegionPhoneNumberFormFieldTest(TestCase):
+class RegionPhoneNumberFormFieldTest(SimpleTestCase):
     def test_regional_phone(self):
         class PhoneNumberForm(forms.Form):
             canadian_number = formfields.PhoneNumberField(region="CA")
@@ -520,45 +520,118 @@ class RegionPhoneNumberModelFieldTest(TestCase):
         self.assertEqual(phonenumbers.parse(ALGERIAN_PHONE_NUMBER), m.phone_number)
         self.assertEqual(ALGERIAN_PHONE_NUMBER, m.phone_number)
 
+    def test_region_field_empty(self):
+        obj = models.TestModelRegionAR.objects.create()
+        form = ARPhoneNumberForm(instance=obj)
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label>'
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
 
-class PhoneNumberOrdering(TestCase):
-    def test_ordering(self):
-        phone1 = PhoneNumber.from_string("+33600000000")
-        phone2 = PhoneNumber.from_string("+33600000001")
-        self.assertLess(phone1, phone2)
-        # Ordering is total.
-        self.assertGreater(phone2, phone1)
-        self.assertLessEqual(phone1, phone1)
-        self.assertGreaterEqual(phone1, phone1)
-        self.assertEqual(phone1, phone1)
+    def test_region_field_renders_international_as_E164(self):
+        form = ARPhoneNumberForm({"phone": "+32468547825"})
+        self.assertTrue(form.is_valid())
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label>'
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="+32468547825" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
 
-    def test_ordering_with_phonenumbers(self):
-        phone1 = PhoneNumber.from_string("+33600000000")
-        phone2 = phonenumbers.parse("+33600000001")
-        self.assertLess(phone1, phone2)
+    def test_region_field_renders_international_as_E164_from_instance(self):
+        obj = models.TestModelRegionAR.objects.create(phone="+32468547825")
+        form = ARPhoneNumberForm(instance=obj)
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label> '
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="+32468547825" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
 
-    def test_ordering_contains_None(self):
-        phone1 = PhoneNumber.from_string("+33600000000")
-        msg = "'<' not supported between instances of 'PhoneNumber' and 'NoneType'"
-        for assertion in [
-            self.assertLess,
-            self.assertLessEqual,
-            self.assertGreater,
-            self.assertGreaterEqual,
-        ]:
-            with self.subTest(assertion):
-                with self.assertRaisesMessage(TypeError, msg):
-                    assertion(phone1, None)
+    def test_region_field_renders_national_numbers_as_national(self):
+        form = ARPhoneNumberForm({"phone": "01145482368"})
+        self.assertTrue(form.is_valid())
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label>'
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="011 4548-2368" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
 
-    def test_ordering_with_invalid_value(self):
-        phone1 = PhoneNumber.from_string("+33600000000")
-        invalid = PhoneNumber.from_string("+1000000000")
-        invalid_phonenumbers = phonenumbers.parse("+1000000000")
-        for number in [invalid, invalid_phonenumbers]:
-            with self.subTest(number):
-                for p1, p2 in [[phone1, number], [number, phone1]]:
-                    with self.subTest([p1, p2]):
-                        with self.assertRaisesRegex(
-                            ValueError, r"^Invalid phone number: "
-                        ):
-                            self.assertLess(p1, p2)
+    def test_region_field_renders_national_numbers_as_national_from_instance(self):
+        obj = models.TestModelRegionAR.objects.create(phone="01145482368")
+        form = ARPhoneNumberForm(instance=obj)
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label> '
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="011 4548-2368" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
+
+    def test_region_field_renders_national_numbers_from_instance_and_form_data(self):
+        obj = models.TestModelRegionAR.objects.create(phone="01145482368")
+        form = ARPhoneNumberForm({"phone": "011 4548-2368"}, instance=obj)
+        self.assertTrue(form.is_valid())
+        self.assertHTMLEqual(
+            form.as_p(),
+            "<p>"
+            '<label for="id_phone">Phone:</label> '
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="011 4548-2368" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
+
+    def test_region_field_renders_invalid_numbers(self):
+        form = ARPhoneNumberForm({"phone": "abcdef"})
+        self.assertFalse(form.is_valid())
+        self.assertHTMLEqual(
+            form.as_p(),
+            '<ul class="errorlist">'
+            "<li>Enter a valid phone number (e.g. 011 2345-6789) "
+            "or a number with an international call prefix.</li>"
+            "</ul>"
+            "<p>"
+            '<label for="id_phone">Phone:</label>'
+            "<input "
+            'type="tel" '
+            'name="phone" '
+            'value="abcdef" '
+            'maxlength="128" '
+            'id="id_phone">'
+            "</p>",
+        )
